@@ -74,7 +74,7 @@ def test_check_file_with_changes(capsys, imperfect) -> None:
 
 
 def test_sorted_imports_multiple_configs() -> None:
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="You can either specify custom configuration options"):
         api.sort_code_string("import os", config=Config(line_length=80), line_length=80)
 
 
@@ -94,6 +94,13 @@ def test_find_imports_in_file(imperfect):
     assert "b" in [found_import.module for found_import in found_imports]
 
 
+def test_find_imports_in_file_error(tmpdir):
+    test_path = tmpdir.join("test_path.py")
+    test_path.mkdir()
+    with pytest.warns(UserWarning):
+        assert not list(api.find_imports_in_file(test_path))
+
+
 def test_find_imports_in_code():
     code = """
 from x.y import z as a
