@@ -1,3 +1,4 @@
+import pytest
 from hypothesis import given, reject
 from hypothesis import strategies as st
 
@@ -93,6 +94,44 @@ from kopf.structs import bodies, configuration, containers, diffs, \\
     )
 
 
+@pytest.mark.parametrize("include_trailing_comma", [False, True])
+@pytest.mark.parametrize("line_length", [18, 19])
+@pytest.mark.parametrize("multi_line_output", [4, 5])
+def test_vertical_grid_size_near_line_length(
+    multi_line_output: int,
+    line_length: int,
+    include_trailing_comma: bool,
+):
+    separator = " "
+    # Cases where the input should be wrapped:
+    if (
+        # Mode 4 always adds a closing ")", making the imports line 19 chars,
+        # if include_trailing_comma is True that becomes 20 chars.
+        (multi_line_output == 4 and line_length < 19 + int(include_trailing_comma))
+        # Modes 5 and 6 only add a comma, if include_trailing_comma is True,
+        # so their lines are 18 or 19 chars long.
+        or (multi_line_output != 4 and line_length < 18 + int(include_trailing_comma))
+    ):
+        separator = "\n    "
+
+    test_input = f"from foo import (\n    aaaa, bbb,{separator}ccc"
+    if include_trailing_comma:
+        test_input += ","
+    if multi_line_output != 4:
+        test_input += "\n"
+    test_input += ")\n"
+
+    assert (
+        isort.code(
+            test_input,
+            multi_line_output=multi_line_output,
+            line_length=line_length,
+            include_trailing_comma=include_trailing_comma,
+        )
+        == test_input
+    )
+
+
 # This test code was written by the `hypothesis.extra.ghostwriter` module
 # and is provided under the Creative Commons Zero public domain dedication.
 
@@ -220,6 +259,24 @@ def test_fuzz_hanging_indent(
         reject()
 
 
+@pytest.mark.parametrize("include_trailing_comma", [True, False])
+def test_hanging_indent__with_include_trailing_comma__expect_same_result(include_trailing_comma):
+    result = isort.wrap_modes.hanging_indent(
+        statement="from datetime import ",
+        imports=["datetime", "time", "timedelta", "timezone", "tzinfo"],
+        white_space=" ",
+        indent="    ",
+        line_length=50,
+        comments=[],
+        line_separator="\n",
+        comment_prefix=" #",
+        include_trailing_comma=include_trailing_comma,
+        remove_comments=False,
+    )
+
+    assert result == "from datetime import datetime, time, timedelta, \\\n    timezone, tzinfo"
+
+
 @given(
     statement=st.text(),
     imports=st.lists(st.text()),
@@ -425,47 +482,6 @@ def test_fuzz_vertical_grid_grouped(
         reject()
 
 
-@given(
-    statement=st.text(),
-    imports=st.lists(st.text()),
-    white_space=st.text(),
-    indent=st.text(),
-    line_length=st.integers(),
-    comments=st.lists(st.text()),
-    line_separator=st.text(),
-    comment_prefix=st.text(),
-    include_trailing_comma=st.booleans(),
-    remove_comments=st.booleans(),
-)
-def test_fuzz_vertical_grid_grouped_no_comma(
-    statement,
-    imports,
-    white_space,
-    indent,
-    line_length,
-    comments,
-    line_separator,
-    comment_prefix,
-    include_trailing_comma,
-    remove_comments,
-):
-    try:
-        isort.wrap_modes.vertical_grid_grouped_no_comma(
-            statement=statement,
-            imports=imports,
-            white_space=white_space,
-            indent=indent,
-            line_length=line_length,
-            comments=comments,
-            line_separator=line_separator,
-            comment_prefix=comment_prefix,
-            include_trailing_comma=include_trailing_comma,
-            remove_comments=remove_comments,
-        )
-    except ValueError:
-        reject()
-
-
 @given(
     statement=st.text(),
     imports=st.lists(st.text()),
